==> cms-db_v0.9.tar.gz: admin/friendlyerror.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

if (!isset($fe_title) or !isset($fe_subtitle) or !isset($fe_content)) {
	die('Missing arguments (friendlyerror.inc.php)');
}

// the same design is used in htaccess data access protection

header('Content-Type: text/html; charset=utf-8');
echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title>'.$fe_title.'</title>
		<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
		<style type="text/css">/* <![CDATA[ */
		html { padding: 0; margin: 0; }
		body { font-family: "Bitstream Vera Sans", Arial, Helvetica sans-serif;
			font-size: 10pt; padding: 0; margin: 1em; background: #eee; color: #000; }
		h1 { font-size: 4em; margin: -.25em -.25em 0 -.25em; padding: .25em;
			background: #ddd; border-bottom: .1em solid #bbb; font-weight: normal; color: #032b4f; }
		h2 { font-size: 1.5em; font-weight: bold; }
		h3 { font-size: 1em; text-decoration: underline; font-weight: normal; }
		a:link, a:visited, a:active, a:hover { color: #00f; text-decoration: none; }
		a:hover { text-decoration: underline; }
		/* ]]> */</style>
	</head>
	<body>
		<h1>cms -db</h1>
		<h2>'.$fe_subtitle.'</h2>
		'.$fe_content.'
	</body>
</html>';
die();
?>

==> cms-db_v0.9.3.tar.gz: admin/friendlyerror.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) die('Something\'s missing. (friendlyerror.inc.php)');

if (!isset($fe_title) or !isset($fe_subtitle) or !isset($fe_content)) {
	die('Missing arguments. (friendlyerror.inc.php)');
}

// the same design is used in htaccess data access protection

header('Content-Type: text/html; charset=utf-8');
echo '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		<title>'.$fe_title.'</title>
		<meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
		<style type="text/css">/* <![CDATA[ */
		html { padding: 0; margin: 0; }
		body { font-family: "Bitstream Vera Sans", Arial, Helvetica sans-serif;
			font-size: 10pt; padding: 0; margin: 1em; background: #eee; color: #000; }
		h1 { font-size: 4em; margin: -.25em -.25em 0 -.25em; padding: .25em;
			background: #ddd; border-bottom: .1em solid #bbb; font-weight: normal; color: #032b4f; }
		h2 { font-size: 1.5em; font-weight: bold; }
		h3 { font-size: 1em; text-decoration: underline; font-weight: normal; }
		a:link, a:visited, a:active, a:hover { color: #00f; text-decoration: none; }
		a:hover { text-decoration: underline; }
		/* ]]> */</style>
	</head>
	<body>
		<h1>cms -db</h1>
		<h2>'.$fe_subtitle.'</h2>
		'.$fe_content.'
	</body>
</html>';
die();
?>
